<?php

/**
 * Enqueue scripts and styles.
 * @return [type] [description]
 */
function rooten_admin_style() {
	wp_register_style('admin-setting', get_template_directory_uri() . '/admin/css/admin-settings.css');
	wp_enqueue_style('admin-setting');
}
add_action('admin_enqueue_scripts', 'rooten_admin_style');


/**
 * Admin related scripts
 * @return [type] [description]
 */
function rooten_admin_script() {
	wp_register_script('admin-setting', get_template_directory_uri() . '/admin/js/admin-settings.js', ['jquery'], ROOTEN_VER, true);

	wp_enqueue_script('admin-setting');
}
add_action('admin_enqueue_scripts', 'rooten_admin_script');


/**
 * Site Stylesheets
 * @return [type] [description]
 */
function rooten_styles() {

	// Load Primary Stylesheet

	if (is_rtl()) {
		wp_enqueue_style('bdt-uikit', ROOTEN_URL . '/css/bdt-uikit.rtl.css', [], '3.11.1', 'all');
	} else {
		wp_enqueue_style('bdt-uikit', ROOTEN_URL . '/css/bdt-uikit.css', [], '3.11.1', 'all');
	}

	if (class_exists('Woocommerce')) {
		wp_enqueue_style('theme-woocommerce-style', ROOTEN_URL . '/css/woocommerce.css', [], ROOTEN_VER, 'all');
	}

	if (get_theme_mod('rooten_header_txt_style', false)) {
		wp_enqueue_style('theme-inverse-style', ROOTEN_URL . '/css/inverse.css', [], '3.11.1', 'all');
	}

	// google font load locally for faster load
	wp_enqueue_style('theme-style', ROOTEN_URL . '/css/default-fonts.css', [], ROOTEN_VER, 'all');

	wp_enqueue_style('rooten-style', get_stylesheet_uri(), [], ROOTEN_VER, 'all');

	wp_style_add_data('rooten-style', 'rtl', 'replace');
}
add_action('wp_enqueue_scripts', 'rooten_styles');

/**
 * Site Scripts
 * @return [type] [description]
 */
function rooten_scripts() {

	$suffix    = defined('SCRIPT_DEBUG') && SCRIPT_DEBUG ? '' : '.min';
	$preloader = get_theme_mod('rooten_preloader');
	$cookie    = get_theme_mod('rooten_cookie');

	if ($preloader) {
		wp_enqueue_script('please-wait', ROOTEN_URL . '/js/please-wait.min.js', [], ROOTEN_VER, false);
	}
	if ($cookie) {
		wp_register_script('cookie-bar', ROOTEN_URL . '/js/jquery.cookiebar.js', [], ROOTEN_VER, true);
		wp_enqueue_script('cookie-bar');
	}

	if (!defined('BDTEP') or !defined('BDTPS')) {
		wp_register_script('bdt-uikit', ROOTEN_URL . '/js/bdt-uikit' . $suffix . '.js', ['jquery'], '3.16.3', true);
		wp_enqueue_script('bdt-uikit');
	}
	
	if (get_theme_mod('rooten_smooth_scroll', 1)) {
		wp_register_script( 'gsap', ROOTEN_URL . '/js/gsap.min.js', [], '3.12.5', true );
		wp_register_script( 'lenis', ROOTEN_URL . '/js/lenis.min.js', [ 'gsap' ], ROOTEN_VER, true );
		wp_register_style( 'lenis', ROOTEN_URL . '/css/lenis.min.css', [], ROOTEN_VER );
		wp_register_script( 'bdt-smooth-scroller', ROOTEN_URL . '/js/rooten-smooth-scroller.js', [ 'jquery-core', 'lenis' ], ROOTEN_VER, true );

		wp_enqueue_style( 'lenis' );
		wp_enqueue_script( 'gsap' );
		wp_enqueue_script( 'lenis' );
		wp_enqueue_script( 'bdt-smooth-scroller' );
	}

	wp_register_script('rooten-script', ROOTEN_URL . '/js/theme.js', ['jquery'], ROOTEN_VER, true);
	wp_enqueue_script('rooten-script');

	// Load WP Comment Reply JS
	if (is_singular()) {
		wp_enqueue_script('comment-reply');
	}
}

add_action('wp_enqueue_scripts', 'rooten_scripts', 99999);
