<?php

defined('ABSPATH') or exit;
/**
 * Rooten Theme Support Class
 * @since 3.1.0
 * @package Rooten
 */
class Rooten_Theme_MetaBox {

    /**
     * Instance of Rooten Theme Support Class
     * @var Rooten Theme Support Class Instance of Rooten Theme Support Class
     * @since 3.1.0
     * @access private
     * @static
     * @var Rooten_Theme_MetaBox
     */
    private static $_instance = null;
    /**
     * Instance of Elementor
     * @var Elementor Instance of Elementor
     * @since 3.1.0
     * @access private
     * @static
     */
    private static $elementor_instance;

    /**
     * Instance of Rooten Theme Support Class
     * @return Rooten Theme Support Class Instance of Rooten Theme Support Class
     */
    public static function instance() {
        if (!isset(self::$_instance)) {
            self::$_instance = new self;
        }

        return self::$_instance;
    }

    /**
     * Constructor
     * @since 3.1.0
     * @access private
     */
    private function __construct() {
        self::$elementor_instance = Elementor\Plugin::instance();
        add_action('admin_init', [$this, 'rooten_page_settings_metabox']);
        add_action('save_post', [$this, 'rooten_custom_template_save_metabox']);
        add_action('admin_enqueue_scripts', [$this, 'enqueue_admin_scripts']);
    }
    /**
     * Rooten Page Settings Metabox
     * @return void
     * @since 3.1.0
     * @access public
     */
    public function rooten_page_settings_metabox() {
        add_meta_box('_pagesettings', __('Page Settings', 'rooten'), [$this, 'rooten_template_metabox_fields_callback'], 'page', 'side');
    }
    /**
     * Rooten Template Metabox Fields Callback
     * @param  mixed $post
     */
    public function enqueue_admin_scripts() {
        wp_enqueue_style('rooetn-metabox-admin-css', get_template_directory_uri() . '/inc/meta-box/assets/css/style.css', null, '1.0.0', false);
        wp_enqueue_script('rooetn-metabox-admin-js', get_template_directory_uri() . '/inc/meta-box/assets/js/script.js', null, '1.0.0', true);
    }

    /**
     * Rooten Template Metabox Fields Callback
     * @param  mixed $post
     *
     */

    private function rooten_get_sidebars_array() {
        global $wp_registered_sidebars;
        $list_sidebars = [];
        foreach ($wp_registered_sidebars as $sidebar) {
            $list_sidebars[$sidebar['id']] = $sidebar['name'];
        }
        // remove them from the list for better understand purpose
        unset($list_sidebars['footer-widgets']);
        unset($list_sidebars['footer-widgets-2']);
        unset($list_sidebars['footer-widgets-3']);
        unset($list_sidebars['footer-widgets-4']);
        unset($list_sidebars['offcanvas']);
        unset($list_sidebars['fixed-left']);
        unset($list_sidebars['fixed-right']);
        unset($list_sidebars['headerbar']);
        unset($list_sidebars['drawer']);
        unset($list_sidebars['bottom']);
        return $list_sidebars;
    }

    /**
     * Rooten Saved Header Template list maker
     * @return template type with array
     * @since 3.1.2
     * @access private
     * @param string $type
     * @return array

     */
    private function rooten_custom_template_list($type = 'header') {

        if (!defined('ELEMENTOR_VERSION')) {
            return ['0' => esc_html__('Install Elementor First', 'rooten')];
        }

        $args = [
            'numberposts' => 20,
            'post_type'   => 'bdt-custom-template',
            'meta_query'   => [
                'relation' => 'OR',
                [
                    'key'     => 'rooten_template_type',
                    'value'   => $type,
                    'compare' => '==',
                    'type'    => 'post',
                ]
            ]
        ];

        $post_list = get_posts($args);

        $post_list_options = [0 => sprintf(__('Select %s', 'rooten'), ucfirst($type))];

        foreach ($post_list as $list) :
            $post_list_options[$list->ID] = $list->post_title;
        endforeach;

        return $post_list_options;
    }

    /**
     * Disiplay the metabox fields for Rooten Custom Template.
     * @since 3.1.2
     * Display metabox fields -> Rooten Custom Template
     */
    function rooten_template_metabox_fields_callback($post) {
        wp_nonce_field('rooten_metabox_page_settings_action', 'rooten_metabox_page_settings_field');

        $label_page_layout         = __('Page Layout', 'rooten');
        $label_sidebar             = __('Sidebar', 'rooten');
        $label_header              = __('Header', 'rooten');
        $label_custom_header       = __('Custom Header', 'rooten');
        $label_footer_widget       = __('Footer Widgets', 'rooten');
        $label_custom_footer       = __('Custom Footer', 'rooten');
        $sidebar_desc              = __('Select the sidebar you wish to display on this page.', 'rooten');
        $header_desc               = __('Override the header style for this page.', 'rooten');
        $footer_widget_desc        = __('Enable or disable the Footer Widgets on this Page.', 'rooten');
        $custom_header_desc        = __('Enable or disable the Footer Widgets on this Page.', 'rooten');
        $custom_footer_desc        = __('Select your custom footer from here.', 'rooten');
        $page_layout_default       = __('<strong>Default:</strong> For usage normal Text Pages', 'rooten');
        $page_layout_full_width    = __('<strong>Full Width:</strong> For pages using Elementor (commonly used)', 'rooten');
        $page_layout_sidebar_left  = __('<strong>Sidebar Left:</strong> Sidebar Left Template', 'rooten');
        $page_layout_sidebar_right = __('<strong>Sidebar Right:</strong> Sidebar Right Template', 'rooten');

        $page_layouts = [
            'default'       => esc_html_x('Default', 'backend', 'rooten'),
            'full'          => esc_html_x('Fullwidth', 'backend', 'rooten'),
            'sidebar-right' => esc_html_x('Sidebar Right', 'backend', 'rooten'),
            'sidebar-left'  => esc_html_x('Sidebar Left', 'backend', 'rooten'),
        ];
        $header_layouts = [
            null       => esc_html_x('Default (as customizer)', 'backend', 'rooten'),
            'custom'   => esc_html_x('Custom', 'backend', 'rooten'),
        ];
        $footer_widgets = [
            null       => esc_html_x('Default (as customizer)', 'backend', 'rooten'),
            'custom'   => esc_html_x('Custom Footer', 'backend', 'rooten'),
        ];
        $sidebars = $this->rooten_get_sidebars_array();
        $custom_headers = $this->rooten_custom_template_list();
        $custom_footer_widgets = rooten_custom_template_list('footer');

        $layout_html = '';
        $selected_layout   = get_post_meta($post->ID, 'rooten_page_layout', true);
        $selected_val = '';

        foreach ($page_layouts as $layout_key => $layout) {
            $selected = '';
            if ($layout_key == $selected_layout) {
                $selected = 'selected';
                $selected_val = $layout_key;
            }
            $layout_html .= sprintf("<option %s value='%s'>%s</option>", $selected, $layout_key, ucwords($layout));
        }

        $sidebar_html = '';
        $selected_sidebar   = get_post_meta($post->ID, 'rooten_sidebar', true);
        foreach ($sidebars as $key => $sidebar) {
            $selected = '';
            if ($key == $selected_sidebar) {
                $selected = 'selected';
            }
            $sidebar_html .= sprintf("<option %s value='%s'>%s</option>", $selected, $key, ucwords($sidebar));
        }

        $header_html = '';
        $selected_header   = get_post_meta($post->ID, 'rooten_header_layout', true);
        foreach ($header_layouts as $header_key => $header) {
            $selected = '';
            if ($header_key == $selected_header) {
                $selected = 'selected';
                $header_selected_val = $header_key;
            }
            $header_html .= sprintf("<option %s value='%s'>%s</option>", $selected, $header_key, ucwords($header));
        }

        $custom_header_html = '';
        $selected_custom_header   = get_post_meta($post->ID, 'rooten_custom_header', true);
        foreach ($custom_headers as $key => $custom_header) {
            $selected = '';
            if ($key == $selected_custom_header) {
                $selected = 'selected';
            }
            $custom_header_html .= sprintf("<option %s value='%s'>%s</option>", $selected, $key, ucwords($custom_header));
        }

        $footer_widget_html = '';
        $selected_footer_widget   = get_post_meta($post->ID, 'rooten_footer_widgets', true);
        foreach ($footer_widgets as $footer_widget_key => $footer_widget) {
            $selected = '';
            if ($footer_widget_key == $selected_footer_widget) {
                $selected = 'selected';
                $footer_selected_val = $footer_widget_key;
            }
            $footer_widget_html .= sprintf("<option %s value='%s'>%s</option>", $selected, $footer_widget_key, ucwords($footer_widget));
        }

        $custom_footer_widget_html = '';
        $selected_footer_widget   = get_post_meta($post->ID, 'rooten_custom_footer', true);
        foreach ($custom_footer_widgets as $key => $custom_footer_widget) {
            $selected = '';
            if ($key == $selected_footer_widget) {
                $selected = 'selected';
            }
            $custom_footer_widget_html .= sprintf("<option %s value='%s'>%s</option>", $selected, $key, ucwords($custom_footer_widget));
        }

        $metabox_html = <<<EOD

        <div class="bdt-metabox-page-settings">
            <div class="bdt-page-layout">
                <div class="page-settings-label">
                    <label for="rooten_page_layout">{$label_page_layout}: </label>
                </div>
                <div class="bdt-metabox-input-fields">
                    <select name="rooten_page_layout" id="rooten_page_layout" data-selected="{$selected_val}">
                        {$layout_html}
                    </select>
                    <p class="page-settings-desc">{$page_layout_default}<br>{$page_layout_full_width}<br>{$page_layout_sidebar_left}<br>{$page_layout_sidebar_right}</p>
                </div>
            </div>
            <div class="bdt-sidebar">
                <div class="page-settings-label">
                    <label for="rooten_sidebar">{$label_sidebar}: </label>
                </div>
                <div class="bdt-metabox-input-fields">
                    <select name="rooten_sidebar" id="rooten_sidebar">
                        {$sidebar_html}
                    </select>
                    <p class="page-settings-desc">{$sidebar_desc}</p>
                </div>
            </div>

            <div class="bdt-header">
                <div class="page-settings-label">
                    <label for="rooten_header_layout">{$label_header}: </label>
                </div>
                <div class="bdt-metabox-input-fields">
                    <select name="rooten_header_layout" id="rooten_header_layout" data-selected="{$header_selected_val}">
                        {$header_html}
                    </select>
                    <p class="page-settings-desc">{$header_desc}</p>
                </div>
            </div>

            <div class="bdt-custom-header">
                <div class="page-settings-label">
                    <label for="rooten_custom_header">{$label_custom_header}: </label>
                </div>
                <div class="bdt-metabox-input-fields">
                    <select name="rooten_custom_header" id="rooten_custom_header">
                        {$custom_header_html}
                    </select>
                    <p class="page-settings-desc">{$custom_header_desc}</p>
                </div>
            </div>

            <div class="bdt-footer">
                <div class="page-settings-label">
                    <label for="rooten_footer_widgets">{$label_footer_widget}: </label>
                </div>
                <div class="bdt-metabox-input-fields">
                    <select name="rooten_footer_widgets" id="rooten_footer_widgets" data-selected="{$footer_selected_val}">
                        {$footer_widget_html}
                    </select>
                    <p class="page-settings-desc">{$footer_widget_desc}</p>
                </div>
            </div>

            <div class="bdt-custom-footer">
                <div class="page-settings-label">
                    <label for="rooten_custom_footer">{$label_custom_footer}: </label>
                </div>
                <div class="bdt-metabox-input-fields">
                    <select name="rooten_custom_footer" id="rooten_custom_footer">
                        {$custom_footer_widget_html}
                    </select>
                    <p class="page-settings-desc">{$custom_footer_desc}</p>
                </div>
            </div>
	</div>
EOD;

        echo $metabox_html; // WPCS: XSS ok.
    }


    /**
     * Save the metabox fields for Rooten Custom Template.
     * @since 3.1.2
     * Save metabox fields -> Rooten Custom Template
     */
    public function rooten_custom_template_save_metabox($post_id) {
        if (!$this->is_secured('rooten_metabox_page_settings_field', 'rooten_metabox_page_settings_action', $post_id)) {
            return $post_id;
        }
        $layout             = isset($_POST['rooten_page_layout']) ? $_POST['rooten_page_layout'] : '';
        $sidebar            = isset($_POST['rooten_sidebar']) ? $_POST['rooten_sidebar'] : '';
        $header             = isset($_POST['rooten_header_layout']) ? $_POST['rooten_header_layout'] : '';
        $footer_widget      = isset($_POST['rooten_footer_widgets']) ? $_POST['rooten_footer_widgets'] : '';
        $custom_header      = isset($_POST['rooten_custom_header']) ? $_POST['rooten_custom_header'] : '';
        $custom_footer      = isset($_POST['rooten_custom_footer']) ? $_POST['rooten_custom_footer'] : '';

        update_post_meta($post_id, 'rooten_page_layout', $layout);
        update_post_meta($post_id, 'rooten_sidebar', $sidebar);
        update_post_meta($post_id, 'rooten_header_layout', $header);
        update_post_meta($post_id, 'rooten_footer_widgets', $footer_widget);
        update_post_meta($post_id, 'rooten_custom_header', $custom_header);
        update_post_meta($post_id, 'rooten_custom_footer', $custom_footer);
    }


    private function is_secured($nonce_field, $action, $post_id) {
        $nonce = isset($_POST[$nonce_field]) ? $_POST[$nonce_field] : '';

        if ($nonce == '') {
            return false;
        }
        if (!wp_verify_nonce($nonce, $action)) {
            return false;
        }

        if (!current_user_can('edit_post', $post_id)) {
            return false;
        }

        if (wp_is_post_autosave($post_id)) {
            return false;
        }

        if (wp_is_post_revision($post_id)) {
            return false;
        }

        return true;
    }
}

/**
 * Initialize the class instance only once.
 * @since 3.1.2
 * @return object
 */
Rooten_Theme_MetaBox::instance();
