<?php

/**
 * Pagination for pages of posts (i.e. includes the "nextpage" <!--nextpage--> Quicktag one or more times).
 * @package rooten
 * @since 1.0.0
 * @version 1.0.0
 * @link https://developer.wordpress.org/reference/functions/wp_link_pages/
 */
function rooten_pagination() {
	if (is_singular())
		return;

	global $wp_query;

	/** Stop execution if there's only 1 page */
	if ($wp_query->max_num_pages <= 1)
		return;

	$paged = get_query_var('paged') ? absint(get_query_var('paged')) : 1;
	$max   = intval($wp_query->max_num_pages);

	/**	Add current page to the array */
	if ($paged >= 1)
		$links[] = $paged;

	/**	Add the pages around the current page to the array */
	if ($paged >= 3) {
		$links[] = $paged - 1;
		$links[] = $paged - 2;
	}

	if (($paged + 2) <= $max) {
		$links[] = $paged + 2;
		$links[] = $paged + 1;
	}

	echo '<div class="tm-pagination"><ul class="bdt-pagination bdt-flex-center">' . "\n";

	/**	Previous Post Link */
	if (get_previous_posts_link())
		printf('<li class="pagination-prev">%s</li>' . "\n", get_previous_posts_link('<span bdt-pagination-previous></span>'));

	/**	Link to first page, plus ellipses if necessary */
	if (!in_array(1, $links)) {
		$class = 1 == $paged ? ' class="current"' : '';

		printf('<li%s><a href="%s">%s</a></li>' . "\n", $class, esc_url(get_pagenum_link(1)), '1');

		if (!in_array(2, $links))
			echo '<li><span>...</span></li>';
	}

	/**	Link to current page, plus 2 pages in either direction if necessary */
	sort($links);
	foreach ((array) $links as $link) {
		$class = $paged == $link ? ' class="bdt-active"' : '';
		printf('<li%s><a href="%s">%s</a></li>' . "\n", $class, esc_url(get_pagenum_link($link)), $link);
	}

	/**	Link to last page, plus ellipses if necessary */
	if (!in_array($max, $links)) {
		if (!in_array($max - 1, $links))
			echo '<li><span>...</span></li>' . "\n";

		$class = $paged == $max ? ' class="bdt-active"' : '';
		printf('<li%s><a href="%s">%s</a></li>' . "\n", $class, esc_url(get_pagenum_link($max)), $max);
	}

	/**	Next Post Link */
	if (get_next_posts_link())
		printf('<li class="pagination-next">%s</li>' . "\n", get_next_posts_link('<span bdt-pagination-next></span>'));

	echo '</ul></div>' . "\n";
}
?>


<?php rooten_pagination(); ?>

<p class="bdt-hidden"><?php posts_nav_link(); ?></p>